# coding: utf-8

"""
    Robust Intelligence REST API

    API methods for Robust Intelligence. Users must authenticate using the `rime-api-key` header.  # noqa: E501

    OpenAPI spec version: 1.0
    Contact: dev@robustintelligence.com
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RimeFailingRowsResult(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'failing_rows': 'list[RimeFailingRow]',
        'top_count': 'str',
        'total_count': 'str',
        'all_included': 'bool',
        'description': 'str'
    }

    attribute_map = {
        'failing_rows': 'failingRows',
        'top_count': 'topCount',
        'total_count': 'totalCount',
        'all_included': 'allIncluded',
        'description': 'description'
    }

    def __init__(self, failing_rows=None, top_count=None, total_count=None, all_included=None, description=None):  # noqa: E501
        """RimeFailingRowsResult - a model defined in Swagger"""  # noqa: E501
        self._failing_rows = None
        self._top_count = None
        self._total_count = None
        self._all_included = None
        self._description = None
        self.discriminator = None
        if failing_rows is not None:
            self.failing_rows = failing_rows
        if top_count is not None:
            self.top_count = top_count
        if total_count is not None:
            self.total_count = total_count
        if all_included is not None:
            self.all_included = all_included
        if description is not None:
            self.description = description

    @property
    def failing_rows(self):
        """Gets the failing_rows of this RimeFailingRowsResult.  # noqa: E501


        :return: The failing_rows of this RimeFailingRowsResult.  # noqa: E501
        :rtype: list[RimeFailingRow]
        """
        return self._failing_rows

    @failing_rows.setter
    def failing_rows(self, failing_rows):
        """Sets the failing_rows of this RimeFailingRowsResult.


        :param failing_rows: The failing_rows of this RimeFailingRowsResult.  # noqa: E501
        :type: list[RimeFailingRow]
        """

        self._failing_rows = failing_rows

    @property
    def top_count(self):
        """Gets the top_count of this RimeFailingRowsResult.  # noqa: E501


        :return: The top_count of this RimeFailingRowsResult.  # noqa: E501
        :rtype: str
        """
        return self._top_count

    @top_count.setter
    def top_count(self, top_count):
        """Sets the top_count of this RimeFailingRowsResult.


        :param top_count: The top_count of this RimeFailingRowsResult.  # noqa: E501
        :type: str
        """

        self._top_count = top_count

    @property
    def total_count(self):
        """Gets the total_count of this RimeFailingRowsResult.  # noqa: E501


        :return: The total_count of this RimeFailingRowsResult.  # noqa: E501
        :rtype: str
        """
        return self._total_count

    @total_count.setter
    def total_count(self, total_count):
        """Sets the total_count of this RimeFailingRowsResult.


        :param total_count: The total_count of this RimeFailingRowsResult.  # noqa: E501
        :type: str
        """

        self._total_count = total_count

    @property
    def all_included(self):
        """Gets the all_included of this RimeFailingRowsResult.  # noqa: E501


        :return: The all_included of this RimeFailingRowsResult.  # noqa: E501
        :rtype: bool
        """
        return self._all_included

    @all_included.setter
    def all_included(self, all_included):
        """Sets the all_included of this RimeFailingRowsResult.


        :param all_included: The all_included of this RimeFailingRowsResult.  # noqa: E501
        :type: bool
        """

        self._all_included = all_included

    @property
    def description(self):
        """Gets the description of this RimeFailingRowsResult.  # noqa: E501


        :return: The description of this RimeFailingRowsResult.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this RimeFailingRowsResult.


        :param description: The description of this RimeFailingRowsResult.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RimeFailingRowsResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RimeFailingRowsResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
